@@ -273,10 +273,6 @@ double MCMCAlgorithm::acceptRejectSynthesisRateLevelForAllGenes(Genome& genome,
 		}
 		logPosterior += std::log(currGeneLogPost) + maxValue2;
 
-
-		if (std::isinf(logPosterior))
-            my_print("\tInfinity reached (Gene: %)\n", i);
-
 		// Get category in which the gene is placed in.
 		// If we use multiple sequence observation (like different mutants),
 		// randMultinom needs a parameter N to place N observations in numMixture buckets
@@ -337,11 +333,6 @@ void MCMCAlgorithm::acceptRejectCodonSpecificParameter(Genome& genome, Model& mo
 		model.calculateLogLikelihoodRatioPerGroupingPerCategory(grouping, genome, acceptanceRatioForAllMixtures);
 		//logPosterior += model.calculateAllPriors();
         double threshold = -Parameter::randExp(1);
-        /*if ((iteration % thinning) == 0)
-        {
-            my_print("The returned logLikelihood Ratio is: %\n", acceptanceRatioForAllMixtures[0]);
-            my_print("The returned Threshhold is: %\n", threshold);
-        }*/
 
 		if (threshold < acceptanceRatioForAllMixtures[0] && std::isfinite(acceptanceRatioForAllMixtures[0]))
 		{
